package com.nisum.employeeservice.controller;

import com.nisum.employeeservice.exception.ResourceNotFoundException;
import com.nisum.employeeservice.model.Employee;
import com.nisum.employeeservice.service.EmployeeService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

import javax.xml.ws.Response;
import java.util.List;
import java.util.Map;
import java.util.Optional;

@CrossOrigin(origins = "*")
@RestController
@RequestMapping("/api/v1")
public class EmployeeController {

  @Autowired EmployeeService employeeService;

  @GetMapping("/employees")
  public List<Employee> getAllEmployees() {
    return employeeService.findAllEmployees();
  }

  @PostMapping("/employees")
  public Employee createEmployee(@RequestBody Employee employee) {
    return employeeService.addEmployee(employee);
  }

  @DeleteMapping("/employees/{id}")
  public Map<String, Boolean> deleteEmployee(@PathVariable(value = "id") Long employeeId) throws ResourceNotFoundException {
    return employeeService.deleteEmployee(employeeId);
  }

  @PutMapping("/employees/{id}")
  public ResponseEntity<Employee> updateEmployee(@PathVariable(value = "id") Long employeeId,
                                                 Employee updatedEmployeeData) throws ResourceNotFoundException {
    Employee updatedEmployee = employeeService.updateEmployee(employeeId, updatedEmployeeData);
    return ResponseEntity.ok(updatedEmployee);
  }

  @GetMapping("/employees/{id}")
  public ResponseEntity<Employee> getEmployeeById(@PathVariable(value = "id") Long employeeId)
          throws ResourceNotFoundException {
    Employee employee = employeeService.getEmployeeById(employeeId).orElseThrow(() -> new ResourceNotFoundException(
            "Employee with id: " + employeeId + " not found"));
    return ResponseEntity.ok().body(employee);
  }


}
